"use client"

import { motion } from "framer-motion"
import { Card, CardContent, CardDescription, CardHeader, CardTitle } from "@/components/ui/card"
import { Brain, LineChart, RefreshCw } from "lucide-react"

export default function Technology() {
  const technologies = [
    {
      icon: <Brain className="h-10 w-10 text-amber-400 golden-neon-glow" />,
      title: "Kullandığımız Yapay Zeka Modelleri",
      description:
        "Çözümlerimiz, makine öğrenimi ve derin öğrenme alanındaki en güncel modeller üzerine inşa edilmiştir.",
      details: [
        "Doğal dil işleme (NLP) için gelişmiş dil modelleri",
        "Görüntü tanıma ve işleme için derin sinir ağları",
        "Öngörücü analizler için makine öğrenimi algoritmaları",
      ],
    },
    {
      icon: <LineChart className="h-10 w-10 text-amber-400 golden-neon-glow" />,
      title: "Minimum Hata, Maksimum Verimlilik",
      description: "AI destekli süreçler, insan hatasını en aza indirerek tutarlı ve güvenilir sonuçlar üretir.",
      details: [
        "Veriye dayalı kararlarla bütçe hatalarını önleme",
        "İçerik üretiminde otomatik hata tespiti ve düzeltme",
        "Manuel işlemlerden kaynaklanan hataları ortadan kaldırma",
      ],
    },
    {
      icon: <RefreshCw className="h-10 w-10 text-amber-400 golden-neon-glow" />,
      title: "Sürekli Öğrenen Sistemler",
      description:
        "Anamur AI'nin teknolojik altyapısı, sürekli güncellenen ve kendi kendine öğrenen sistemlerden oluşur.",
      details: [
        "Yeni verilerle beslenen ve gelişen makine öğrenimi modelleri",
        "Zamanla artan pazarlama kampanyası performansı",
        "Değişen piyasa trendlerine ve müşteri davranışlarına hızlı uyum",
      ],
    },
  ]

  const containerVariants = {
    hidden: { opacity: 0 },
    visible: {
      opacity: 1,
      transition: {
        staggerChildren: 0.2,
      },
    },
  }

  const itemVariants = {
    hidden: { opacity: 0, y: 20 },
    visible: {
      opacity: 1,
      y: 0,
      transition: { duration: 0.5 },
    },
  }

  return (
    <section className="py-20 relative" id="technology">
      <div className="container relative z-10">
        <div className="text-center mb-16">
          <h2 className="text-4xl font-bold mb-4 golden-text">Teknoloji</h2>
          <p className="text-muted-foreground max-w-2xl mx-auto">
            En ileri teknolojiyi kalbinde taşıyan Anamur AI, yapay zeka alanındaki gelişmeleri yakından takip eder ve
            hizmetlerine entegre eder.
          </p>
        </div>

        <motion.div
          className="grid md:grid-cols-3 gap-8"
          variants={containerVariants}
          initial="hidden"
          whileInView="visible"
          viewport={{ once: true, amount: 0.2 }}
        >
          {technologies.map((tech, index) => (
            <motion.div key={index} variants={itemVariants}>
              <Card className="h-full glass-card hover:neon-border transition-all duration-300">
                <CardHeader>
                  <div className="mb-4">{tech.icon}</div>
                  <CardTitle className="text-xl text-white">{tech.title}</CardTitle>
                  <CardDescription className="text-muted-foreground">{tech.description}</CardDescription>
                </CardHeader>
                <CardContent>
                  <ul className="space-y-2">
                    {tech.details.map((detail, i) => (
                      <li key={i} className="flex items-start">
                        <span className="text-primary mr-2">•</span>
                        <span className="text-gray-300">{detail}</span>
                      </li>
                    ))}
                  </ul>
                </CardContent>
              </Card>
            </motion.div>
          ))}
        </motion.div>
      </div>
    </section>
  )
}

